#[repr(u32)]pub enum LowPowerMode {
RemainInRun = 0,
TransferToWait = 1,
TransferToStop = 2,
}Expand description
Low power mode.
From the reference manual,
Setting the low power mode that system will enter on next assertion of dsm_request signal.
Practically, this affects the processor behavior when you use WFI, WFE, or enter another low-power state. Low-power settings that aren’t “run” halt the ARM SYSTICK peripheral.
Variants
RemainInRun = 0
Remain in run mode when entering low power.
TransferToWait = 1
Move to wait mode when entering low power.
TransferToStop = 2
Stop when entering low power.