BandwidthControl

Enum BandwidthControl 

#[repr(u16)]
pub enum BandwidthControl { Stall4Cycles = 2, Stall8Cycles = 3, }
Throttles the amount of bus bandwidth consumed by the eDMA

Defines the number of stalls that the DMA engine will insert between most element transfers.

Some stalls may not occur to minimize startup latency. See the reference manual for more details.

Variants



Stall4Cycles = 2

DMA engine stalls for 4 cycles after each R/W.



Stall8Cycles = 3

DMA engine stalls for 8 cycles after each R/W.