ValueRegister

Enum ValueRegister 

pub enum ValueRegister {
    Val0,
    Val1,
    Val2,
    Val3,
    Val4,
    Val5,
}
PWM value registers.

These value registers describe when PWM counters reset, and when outputs turn on and off. Consider using more descriptive constants, enums, and const functions to describe these values.

Variants



Val0



Val1



Val2

The turn_on() register for Channel::A.



Val3

The turn_off() register for Channel::A.



Val4

The turn_on() register for Channel::B.



Val5

The turn_off() register for Channel::B.