pub struct Output { /* private fields */ }Expand description
An output GPIO.
Implementations
Sourceimpl Output
impl Output
Sourcepub fn toggle(&self)
pub fn toggle(&self)
Alternate the GPIO pin output.
toggle is implemented in hardware, so it will be more efficient
than implementing in software.
Sourcepub fn is_pad_high(&self) -> bool
pub fn is_pad_high(&self) -> bool
Returns true if the value of the pad is high.
Can differ from is_set(), especially in an open drain config.
Sourcepub fn without_pin(port: &mut Port, offset: u32) -> Self
pub fn without_pin(port: &mut Port, offset: u32) -> Self
Allocate an output GPIO without a pin.
Prefer using Port::output to create a GPIO output with a
pin resource. That method ensures that pin resources are managed throughout
your program, and that the pin is configured to operate as a GPIO output.
You may use this method to allocate duplicate Output object for the same
physical GPIO output. This is considered safe, since the Output API is
reentrant.
If you use this constructor, you’re responsible for configuring the IOMUX multiplexer register.