ControllerCommand

Enum ControllerCommand 

#[non_exhaustive]
pub enum ControllerCommand { Transmit { byte: u8, }, Receive { count: u8, }, Stop, ReceiveAndDiscard { drop: u8, }, Start { addr: u8, expect: Response, }, }
LPI2C controller commands.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Transmit

A transmit command.

Fields

byte: u8

The data byte to enqueue.



Receive

A receive command.

Fields

count: u8

How many bytes to receive.



Stop

Generate a STOP condition.



ReceiveAndDiscard

Receive and discard.

Fields

drop: u8

How many bytes to receive and drop.



Start

Generate a (repeated) start, transmit the address addr, and expect the expect response from a device.

Fields

addr: u8

The device you’re addressing.

You’re responsible for shifting the address, and setting the read/write bit. Consider using the read() and write() methods for this purpose.

expect: Response

The expected response from the device.

Implementations

Source

impl ControllerCommand

pub const fn read(addr: u8) -> Self

Creates a (repeat) start command that describes a read from a device with address addr.

The expected response is ACK.

pub const fn write(addr: u8) -> Self

Creates a (repeat) start command that describes a write to a device with address addr.

The expected response is ACK.