pub struct Status(/* private fields */);Expand description
Status flags for the LPSPI interface.
Implementations
Sourceimpl Status
impl Status
Sourcepub const DATA_MATCH: Self
pub const DATA_MATCH: Self
Data match flag.
Indicates that received data has matched one or both of the match fields. To clear this flag, write this bit to the status register (W1C).
Sourcepub const RECEIVE_ERROR: Self
pub const RECEIVE_ERROR: Self
Receive error flag.
Set when the receive FIFO has overflowed. Before clearing this bit, empty the receive FIFO. Then, write this bit to clear the flag (W1C).
Sourcepub const TRANSMIT_ERROR: Self
pub const TRANSMIT_ERROR: Self
Transmit error flag.
Set when the transmit FIFO has underruns. Before clearing this bit, end the transfer. Then, write this bit to clear the flag (W1C).
Sourcepub const TRANSFER_COMPLETE: Self
pub const TRANSFER_COMPLETE: Self
Transfer complete flag.
Set when the LPSPI returns to an idle state, and the transmit FIFO is empty. To clear this flag, write this bit (W1C).
Sourcepub const FRAME_COMPLETE: Self
pub const FRAME_COMPLETE: Self
Frame complete flag.
Set at the end of each frame transfer, when PCS negates. To clear this flag, write this bit (W1C).
Sourcepub const WORD_COMPLETE: Self
pub const WORD_COMPLETE: Self
Word complete flag.
Set when the last bit of a received word is sampled. To clear this flag, write this bit (W1C).
Sourcepub const RECEIVE_DATA: Self
pub const RECEIVE_DATA: Self
Receive data flag.
Set when the number of words in the receive FIFO is greater than the watermark. This flag is read only. To clear the flag, exhaust the receive FIFO.
Sourcepub const TRANSMIT_DATA: Self
pub const TRANSMIT_DATA: Self
Transmit data flag.
Set when the number of words in the transmit FIFO is less than or equal to the watermark. This flag is read only. TO clear the flag, fill the transmit FIFO.
Sourceimpl Status
impl Status
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl Status
impl Status
Sourcepub const fn iter(&self) -> Iter<Status>
pub const fn iter(&self) -> Iter<Status>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<Status>
pub const fn iter_names(&self) -> IterNames<Status>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.