PinPortIncompatibleError

Struct PinPortIncompatibleError 

pub struct PinPortIncompatibleError<P>(/* private fields */);
The wrapped pin is not compatible with this peripheral instance.

If P is (), it indicates that the caller’s pin was incompatible with the peripheral, but the method did not take ownership of a pin.

Implementations

Source

impl<P> PinPortIncompatibleError<P>

pub fn pin(self) -> P

Acquire the pin from this error.