pub struct PinPortIncompatibleError<P>(/* private fields */);Expand description
The wrapped pin is not compatible with this peripheral instance.
If P is (), it indicates that the caller’s pin was incompatible with the
peripheral, but the method did not take ownership of a pin.
Implementations
Sourceimpl<P> PinPortIncompatibleError<P>
impl<P> PinPortIncompatibleError<P>